#include "ti84pce.inc"
	.org UserMem-2
	.db tExtTok,tAsm84CeCmp
main:

	call _RclAns
	ex de, hl
	ld a, (hl)
	cp 0
	ret z

	ld c, (hl)
	inc hl
	ld b, (hl)
	inc hl

	push bc
	push hl
	ld de, name1
	ldir
	pop hl
	pop bc

	push bc
	push hl
	ld de, name2
	ldir
	pop hl
	pop bc

	push bc
	push hl
	ld de, name3
	ldir
	pop hl
	pop bc

	ld hl, name1
	add hl, bc
	ld a, '1'
	ld (hl), a

	ld hl, name2
	add hl, bc
	ld a, '2'
	ld (hl), a

	ld hl, name3
	add hl, bc
	ld a, '3'
	ld (hl), a

	call _RunIndicOff

	call drawSplash

	ld a, (error)
	cp 1
	call nz, _GetKey

	ld a, (error)
	cp 1
	call nz, _boot_ClearVRAM

	call _RunIndicOn	
	call _drawStatusBar

	ret

drawSplash:

	ld bc, 4
	ld hl, identity
	ld de, fileIdentity
	ldir

	ld bc, nameend1-name1
	ld hl, name1
	ld de, fileName
	ldir
	call drawSplash1

	ld a, (error)
	cp 1
	jr z, majorError

	ld bc, nameend2-name2
	ld hl, name2
	ld de, fileName
	ldir
	call drawSplash2

	ld a, (error)
	cp 1
	jr z, majorError

	ld bc, nameend3-name3
	ld hl, name3
	ld de, fileName
	ldir
	call drawSplash3

	ld a, (error)
	cp 1
	jr z, majorError

	ret

majorError:
	call _boot_clearVRam
	ld hl, errorMsg
	call _PutS
	call _NewLine
	ret

errorMsg:
	.db "An error has occurred.",0

drawSplash1:
	call openFile
	jr nz, drawSplashErr
	ex de, hl
	ld de, vRAM
	ld bc, 51200
	ldir
	call closeFile
	ret
drawSplash2:
	call openFile
	jr nz, drawSplashErr
	ex de, hl
	ld de, vRAM+(320*80*2)
	ld bc, 51200
	ldir
	call closeFile
	ret
drawSplash3:
	call openFile
	jr nz, drawSplashErr
	ex de, hl
	ld de, vRAM+(320*80*4)
	ld bc, 51200
	ldir
	call closeFile
	ret
drawSplashErr:
	ld a, 1
	ld (error), a
	ret


error:
	.db 0

yes:
	ld a, 'Y'
	call _PutC
	call _NewLine
	ret
no:
	ld a, 'N'
	call _PutC
	call _NewLine
	ret


;-----------------------------------;
;          Close an appVar          ;
;-----------------------------------;
;Input:                             ;
;-----------------------------------;
; fileName       eight-bytes        ;
;-----------------------------------;
closeFile:

	ld hl, fileNamePrefix
	call _Mov9ToOP1
	call _chkFindSym
	ret c

	ld a, b
	cp 100
	ret c

	call _Arc_Unarc

	ret 

;-----------------------------------;
;     Open an appVar PROPERLY       ;
;-----------------------------------;
;Input:                             ;
;-----------------------------------;
; fileName       eight-bytes        ;
; fileIdentity   four-bytes         ;
;-----------------------------------;
;Output:                            ;
;-----------------------------------;
; z              success            ;
; nz             file error         ;
; de             start of file data ;
;-----------------------------------;
openFile:
	call openFileBare
	ret nz
	call identifyFile
	ret 

;-----------------------------------;
;          Open an appVar           ;
;-----------------------------------;
;Input:                             ;
;-----------------------------------;
; fileName       eight-bytes        ;
;-----------------------------------;
;Output:                            ;
;-----------------------------------;
; z              file exists        ;
; nz             file doesn't exist ;
; de             start of file      ;
;-----------------------------------;
openFileBare:

	ld hl, fileNamePrefix
	call _Mov9ToOP1
	call _chkFindSym
	jr c, openFileBareNotFound

	ld a, 100
	cp b
	jr c, openFileBareDontUnarc

	call _Arc_Unarc

openFileBareDontUnarc:

	ld a, (de)
	ld (fileSize), a
	inc de
	ld a, (de)
	ld (fileSize+1), a
	inc de
	ld a, 0
	cp 0

	ret

openFileBareNotFound:
	ld a, 1
	cp 0
	ret

;-----------------------------------;
;        Create an appVar           ;
;-----------------------------------;
; fileName         eight-bytes      ;
; fileSize         two-bytes        ;
; fileIdentity     four-bytes       ;
;-----------------------------------;
createFile:

	;load name into OP1
	ld hl, fileNamePrefix
	call _Mov9ToOP1

	;get file size
	ld hl, (fileSize)
	inc hl \ inc hl \ inc hl \ inc hl
	call _CreateAppVar

	inc de
	inc de
	
	ld hl, fileIdentity
	ld bc, 4
	ldir

	ret

;-----------------------------------;
;     Check appVar identifier       ;
;-----------------------------------;
; fileIdentity     four-bytes       ;
;-----------------------------------;
identifyFile:
	ld hl, fileIdentity
	ex de, hl
	ld bc, 4
identifyFileLoop:
	ld a, (de)
	cp (hl)
	jr nz, identifyFileInvalid
	or a
	inc de
	inc hl
	dec bc
	ld a, c
	cp 0
	jr nz, identifyFileLoop
indentifyFileValid:
	ex de, hl
	ld a, 0
	cp 0
	ret
identifyFileInvalid:
	ex de, hl
	ld a, 0
	cp 1
	ret

;-----------------------------------;
;     Clear contents of a file      ;
;-----------------------------------;
;Input:                             ;
;-----------------------------------;
; de               start of file    ;
;-----------------------------------;
;Output:                            ;
;-----------------------------------;
; de               start of file    ;
;-----------------------------------;
clearFile:
	ret

fileNamePrefix:
	.db AppVarObj
fileName:
	.db 0,0,0,0,0,0,0,0
fileSize:
	.db 0,0,0
fileIdentity:
	.db 0,0,0,0
filePos:
	.db 0,0,0

name:
	.db 0,0,0,0,0,0,0,0,0


name1:
	.db 0,0,0,0,0,0,0,0,0
nameend1:
name2:
	.db 0,0,0,0,0,0,0,0,0
nameend2:
name3:
	.db 0,0,0,0,0,0,0,0,0
nameend3:

identity:
	.db 01,03,01,02

